@@ -1219,6 +1219,7 @@ dosval(char *colstr, double rowdoub)
     size_t l;
 
     llabel = (ep = getent(colstr, rowdoub)) ? (ep -> label) : "";
+    if (llabel == 0) llabel = "";
     l = strlen(llabel) + 1;
     buf = scxmalloc(l);
     strlcpy(buf, llabel, l);
@@ -2046,7 +2047,7 @@ str_search(char *s, int firstrow, int firstcol, int lastrow, int lastcol,
 	scxfree(s);
 	tmp = scxmalloc(160);
 	regerror(errcode, &preg, tmp, sizeof(tmp));
-	error(tmp);
+	error("%s", tmp);
 	scxfree(tmp);
 	return;
     }
@@ -2054,7 +2055,7 @@ str_search(char *s, int firstrow, int firstcol, int lastrow, int lastcol,
 #if defined(RE_COMP)
     if ((tmp = re_comp(s)) != NULL) {
 	scxfree(s);
-	error(tmp);
+	error("%s", tmp);
 	return;
     }
 #endif
