@@ -14,6 +14,10 @@
 #include <stdio.h>
 #endif
 
+#if defined (__unix__) || (defined (__APPLE__) && defined (__MACH__))
+#include <unistd.h>
+#endif
+
 #define CLEAR_LINE error("%s", "") /* suppress warning on NetBSD curses */
 #define	ATBL(tbl, row, col)	(*(tbl + row) + (col))
 
@@ -46,7 +50,9 @@
 #else
 # define error if (isatty(fileno(stdout)) && !move(1,0) && !clrtoeol()) printw
 #endif
-#define	FBUFLEN	1024	/* buffer size for a single field */
+#ifndef FBUFLEN
+#  define       FBUFLEN 1024    /* buffer size for a single field */
+#endif
 #define PATHLEN (PATH_MAX < 8192 ? 8192 : PATH_MAX) /* maximum path length */
 
 #ifndef DFLT_PAGER
@@ -390,7 +396,6 @@ extern	int framerows;		/* Rows in current frame */
 extern	int framecols;		/* Columns in current frame */
 extern	char mode_ind;		/* Mode indicator */
 extern	int	seenerr;
-extern	char	*rev;
 
 extern	FILE *openfile(char *, size_t, int *, int *);
 extern	char *coltoa(int col);
@@ -655,12 +660,12 @@ void nopipe(int);
 void winchg(int);
 # endif
 #else
-int doquit();
-int time_out();
-int dump_me();
-int nopipe();
+int doquit(int);
+int time_out(int);
+int dump_me(int);
+int nopipe(int);
 # ifdef	SIGWINCH
-int winchg();
+int winchg(int);
 # endif
 #endif
 void gohome(void);
